﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing;

namespace CityPlanner
{
    public abstract class Building
    {
        protected Point _Location;
        protected Size _Size;

        public Point Location { get { return _Location; } }
        public Size Size { get { return _Size; } }
        public Int32 Area { get { return _Size.Width * _Size.Height; } }
        public abstract Int32 JobCount { get; }
        public abstract Int32 ResidentCount { get; }

        public Building(Int32 x, Int32 y, Int32 width, Int32 height) 
        {
            _Location = new Point(x, y);
            _Size = new Size(width, height);
        }
    }

    public class ResidentialBuilding : Building 
    {
        private Int32 _FloorCount;
        private Int32 _FlatCount;
        private Int32 _EstimatedResidentCount;

        public override Int32 JobCount
        {
            get { return _FloorCount * _FlatCount / 20; }
        }

        public override Int32 ResidentCount
        {
            get { return _FloorCount * _FlatCount * _EstimatedResidentCount; }
        }

        public ResidentialBuilding(Int32 x, Int32 y, Int32 width, Int32 height, Int32 floors, Int32 flats, Int32 estResidents)
            : base(x, y, width, height)
        {
            _FloorCount = floors;
            _FlatCount = flats;
            _EstimatedResidentCount = estResidents;
        }

    }

    public class CommercialBuilding : Building
    { 
        private Int32 _OfficeCount;
        private Int32 _EstimatedJobCount;

        public override Int32 JobCount
        {
            get { return _OfficeCount * _EstimatedJobCount + _OfficeCount / 10 + 1; }
        }

        public override Int32 ResidentCount
        {
            get { return _OfficeCount; }
        }

        public CommercialBuilding(Int32 x, Int32 y, Int32 width, Int32 height, Int32 offices, Int32 estJobs)
            : base(x, y, width, height)
        {
            _OfficeCount = offices;
            _EstimatedJobCount = estJobs;
        }
    }

    public class IndustryBuilding : Building
    { 
        private Int32 _JobCount;
        
        public override Int32 JobCount
        {
            get { return _JobCount; }
        }

        public override Int32 ResidentCount
        {
            get { return 0; }
        }

        public IndustryBuilding(Int32 x, Int32 y, Int32 width, Int32 height, Int32 jobs)
            : base(x, y, width, height)
        {
            _JobCount = jobs;
        }
    }
}
