﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace CityPlanner
{
    public partial class MainForm : Form
    {
        private List<Building> _BuildingList;
        private OpenFileDialog _OpenFileDialog;

        public MainForm()
        {
            InitializeComponent();
        }

        private void LoadBuildings(String fileName) 
        {
            StreamReader reader = new StreamReader(fileName);
            try
            {
                while (!reader.EndOfStream)
                {
                    String[] line = reader.ReadLine().Split(' ');
                    switch (line[0])
                    {
                        case "1":
                            _BuildingList.Add(new IndustryBuilding(Int32.Parse(line[1]), Int32.Parse(line[2]), Int32.Parse(line[3]), Int32.Parse(line[4]), Int32.Parse(line[5])));
                            break;
                        case "2":
                            _BuildingList.Add(new CommercialBuilding(Int32.Parse(line[1]), Int32.Parse(line[2]), Int32.Parse(line[3]), Int32.Parse(line[4]), Int32.Parse(line[5]), Int32.Parse(line[6])));
                            break;
                        case "3":
                            _BuildingList.Add(new ResidentialBuilding(Int32.Parse(line[1]), Int32.Parse(line[2]), Int32.Parse(line[3]), Int32.Parse(line[4]), Int32.Parse(line[5]), Int32.Parse(line[6]), Int32.Parse(line[7])));
                            break;
                    }
                }
                reader.Close();
            }
            catch (Exception ex)
            {
                reader.Close();
                throw ex;
            }
        }
        private void FillNumbers() 
        {
            Int32 jobCount = 0, residentCount = 0, totalArea = 0, buildingCount = 0;
            foreach (Building building in _BuildingList)
            {

                jobCount += building.JobCount;
                residentCount += building.ResidentCount;
                totalArea += building.Area;
                buildingCount++;
            }
            _LabelJobCount.Text = "Munkahelyek száma: " + jobCount;
            _LabelResidentCount.Text = "Lakóhelyek száma: " + residentCount;
            if (buildingCount > 0)
                _LabelAvgTerritory.Text = "Átlagos alapterület: " + (totalArea / buildingCount);
            else
                _LabelAvgTerritory.Text = "Átlagos alapterület: 0";
        }
        private void DrawBuildings()
        {
            Graphics gr = _Panel.CreateGraphics();
            gr.FillRectangle(Brushes.LightGray, 0, 0, _Panel.Width, _Panel.Height);
            foreach (Building building in _BuildingList)
            {
                if (building is ResidentialBuilding)
                    gr.FillRectangle(Brushes.Green, building.Location.X - building.Size.Width / 2, building.Location.Y - building.Size.Height / 2, building.Size.Width, building.Size.Height);
                if (building is CommercialBuilding)
                    gr.FillRectangle(Brushes.Blue, building.Location.X - building.Size.Width / 2, building.Location.Y - building.Size.Height / 2, building.Size.Width, building.Size.Height);
                if (building is IndustryBuilding)
                    gr.FillRectangle(Brushes.Yellow, building.Location.X - building.Size.Width / 2, building.Location.Y - building.Size.Height / 2, building.Size.Width, building.Size.Height);
            }
        }

        private void MainForm_Load(object sender, EventArgs e)
        {
            _BuildingList = new List<Building>();            
        }

        private void ButtonLoadData_Click(object sender, EventArgs e)
        {
            _BuildingList.Clear();
            try
            {
                _OpenFileDialog = new OpenFileDialog();
                _OpenFileDialog.Title = "Tervrajz betöltése";
                _OpenFileDialog.Filter = "Szövegdfájlok (*.txt)|*.txt";
                if (_OpenFileDialog.ShowDialog() == System.Windows.Forms.DialogResult.OK)
                {
                    LoadBuildings(_OpenFileDialog.FileName);
                    FillNumbers();
                    DrawBuildings();
                }
            }
            catch (Exception ex)
            {
                _BuildingList.Clear();
                MessageBox.Show("Az adatok betöltése sikertelen!");
            }

        }
    }
}
